@@ -47,11 +47,11 @@ setMethod("show", "GroupedIRanges",
     function(object) show(as.data.frame(object))
 )
 
-setMethod(IRanges:::extractROWS, "GroupedIRanges",
+setMethod("extractROWS", "GroupedIRanges",
     function(x, i)
     {
-        i <- IRanges:::extractROWS(setNames(seq_along(x), names(x)), i)
-        x@group <- IRanges:::extractROWS(x@group, i)
+        i <- extractROWS(setNames(seq_along(x), names(x)), i)
+        x@group <- extractROWS(x@group, i)
         callNextMethod()
     }
 )
@@ -62,9 +62,9 @@ setMethod("c", "GroupedIRanges",
         if (!identical(recursive, FALSE))
             stop("\"c\" method for GroupedIRanges objects ",
                  "does not support the 'recursive' argument")
-        old_val <- IRanges:::disableValidity()
-        on.exit(IRanges:::disableValidity(old_val))
-        IRanges:::disableValidity(TRUE)
+        old_val <- S4Vectors:::disableValidity()
+        on.exit(S4Vectors:::disableValidity(old_val))
+        S4Vectors:::disableValidity(TRUE)
         ans <- callNextMethod(x, ..., recursive=FALSE)
         ans@group <-
             do.call(c, lapply(unname(list(x, ...)), function(arg) arg@group))
@@ -193,10 +193,6 @@ setMethod("relistToClass", "XVector",
     function(x) paste0(class(x), "List")
 )
 
-setMethod("splitAsListReturnedClass", "XVector",
-    function(x) {.Deprecated("relistToClass"); paste0(class(x), "List")}
-)
-
 ### Takes one XVector object ('x') and a Ranges object ('i') defining
 ### 1-based ranges on 'x' (conceptually equivalent to defining views on
 ### subject 'x').
@@ -263,17 +259,17 @@ XVectorList.getElement <- function(x, i)
 setMethod("[[", "XVectorList",
     function(x, i, j, ..., exact=TRUE)
     {
-        i <- IRanges:::normalizeDoubleBracketSubscript(i, x)
+        i <- normalizeDoubleBracketSubscript(i, x)
         XVectorList.getElement(x, i)
     }
 )
 
-setMethod(IRanges:::extractROWS, "XVectorList",
+setMethod("extractROWS", "XVectorList",
     function(x, i)
     {
-        i <- IRanges:::extractROWS(setNames(seq_along(x), names(x)), i)
-        x@ranges <- IRanges:::extractROWS(x@ranges, i)
-        x@elementMetadata <- IRanges:::extractROWS(x@elementMetadata, i)
+        i <- extractROWS(setNames(seq_along(x), names(x)), i)
+        x@ranges <- extractROWS(x@ranges, i)
+        x@elementMetadata <- extractROWS(x@elementMetadata, i)
         ## Drop unused pool elements.
         x <- .dropUnusedPoolElts(x)
         x
@@ -307,9 +303,9 @@ setMethod("subseq", "XVectorList",
 ### It's easy to implement specific "c" methods for XVectorList subclasses.
 ### Typically they just need to do something like:
 ###
-###     old_val <- IRanges:::disableValidity()
-###     on.exit(IRanges:::disableValidity(old_val))
-###     IRanges:::disableValidity(TRUE)
+###     old_val <- S4Vectors:::disableValidity()
+###     on.exit(S4Vectors:::disableValidity(old_val))
+###     S4Vectors:::disableValidity(TRUE)
 ###     ans <- callNextMethod(x, ..., recursive=FALSE)
 ###     ...
 ###
@@ -371,7 +367,7 @@ unlist_list_of_XVectorList <- function(Class, x,
     ans_ranges@group <- ans_ranges@group + offsets
 
     ## Combine "mcols" slots.
-    ans_mcols <- do.call(IRanges:::rbind.mcols, x)
+    ans_mcols <- do.call(S4Vectors:::rbind_mcols, x)
 
     ## Make 'ans' and return it.
     ans <- new(Class, pool=ans_pool,
@@ -405,7 +401,7 @@ setMethod("c", "XVectorList",
 setReplaceMethod("[[", "XVectorList",
     function(x, i, j, ..., value)
     {
-        i <- IRanges:::normalizeDoubleBracketSubscript(i, x)
+        i <- normalizeDoubleBracketSubscript(i, x)
         if (!is(value, elementType(x)))
             stop("supplied replacement value must be a ",
                  elementType(x), " object")
